from __future__ import annotations

from loguru import logger


def main() -> None:
    logger.info("fin-infra CLI coming soon. Try the README Quickstart in Python for now.")


if __name__ == "__main__":
    main()
